aboutsummaryrefslogtreecommitdiffstats
path: root/coin/provisioning/common/windows/python.ps1
diff options
context:
space:
mode:
Diffstat (limited to 'coin/provisioning/common/windows/python.ps1')
-rw-r--r--coin/provisioning/common/windows/python.ps15
1 files changed, 4 insertions, 1 deletions
diff --git a/coin/provisioning/common/windows/python.ps1 b/coin/provisioning/common/windows/python.ps1
index e2855c75..aee4c199 100644
--- a/coin/provisioning/common/windows/python.ps1
+++ b/coin/provisioning/common/windows/python.ps1
@@ -3,7 +3,7 @@
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: http://www.qt.io/licensing/
##
## This file is part of the test suite of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL21$
## Commercial License Usage
@@ -83,4 +83,7 @@ if (IsProxyEnabled) {
}
Run-Executable "$targetDir\Scripts\pip.exe" "$pip_args install virtualenv"
+# Install PyPDF2 for QSR documentation
+Run-Executable "$targetDir\Scripts\pip.exe" "$pip_args install PyPDF2"
+
Write-Output "Python-$archVer = $version" >> ~/versions.txt
@@ -3,7 +3,7 @@
## Contact: http://www.qt.io/licensing/
##
-## This file is part of the test suite of the Qt Toolkit.
+## This file is part of the provisioning scripts of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL21$